secret

package
v0.2.30 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 13, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Compare

func Compare(encrypted, plain string) error

Compare compares the encrypted text with the plain text if it's the same.

func CompareBytes

func CompareBytes(encrypted, plain []byte) error

CompareBytes compares the encrypted bytes with the plain bytes if it's the same.

func Encrypt

func Encrypt(v string) (string, error)

Encrypt encrypts the plain text with bcrypt.

func EncryptBytes

func EncryptBytes(v []byte) (string, error)

EncryptBytes encrypts the bytes with bcrypt.

Types

This section is empty.

Jump to